@@ -110,6 +110,7 @@ __all__ = (
     "ModifyReplicationInstanceResponseTypeDef",
     "ModifyReplicationSubnetGroupResponseTypeDef",
     "ModifyReplicationTaskResponseTypeDef",
+    "MoveReplicationTaskResponseTypeDef",
     "PaginatorConfigTypeDef",
     "RebootReplicationInstanceResponseTypeDef",
     "RefreshSchemasResponseTypeDef",
@@ -676,6 +677,7 @@ ReplicationTaskTypeDef = TypedDict(
         "ReplicationTaskArn": str,
         "ReplicationTaskStats": "ReplicationTaskStatsTypeDef",
         "TaskData": str,
+        "TargetReplicationInstanceArn": str,
     },
     total=False,
 )
@@ -1029,6 +1031,10 @@ ModifyReplicationTaskResponseTypeDef = TypedDict(
     total=False,
 )
 
+MoveReplicationTaskResponseTypeDef = TypedDict(
+    "MoveReplicationTaskResponseTypeDef", {"ReplicationTask": "ReplicationTaskTypeDef"}, total=False
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
